From b114f079eed38e53a4aa270297124c7a2938b0a4 Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Wed, 10 Aug 2011 22:19:39 +0000
Subject: rename the following methods: tqparent parent tqmask mask

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/adept@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 adept/adept/acqprogress.cpp              | 12 ++++----
 adept/adept/acqprogress.h                | 10 +++----
 adept/adept/acqprogresswidget.cpp        |  4 +--
 adept/adept/acqprogresswidget.h          |  2 +-
 adept/adept/application.cpp              |  4 +--
 adept/adept/changelog.h                  |  2 +-
 adept/adept/desktoplist.cpp              |  4 +--
 adept/adept/desktoplist.h                |  2 +-
 adept/adept/easytagfilter.cpp            |  4 +--
 adept/adept/easytagfilter.h              |  2 +-
 adept/adept/extendablelist.cpp           |  8 +++---
 adept/adept/extendablelist.h             |  4 +--
 adept/adept/filterlist.cpp               |  4 +--
 adept/adept/filterlist.h                 |  2 +-
 adept/adept/filterwidget.h               |  4 +--
 adept/adept/lister.cpp                   | 20 ++++++-------
 adept/adept/lister.h                     | 12 ++++----
 adept/adept/quickfilter.cpp              |  4 +--
 adept/adept/quickfilter.h                |  2 +-
 adept/adept/statefilter.cpp              | 38 ++++++++++++-------------
 adept/adept/statefilter.h                | 48 ++++++++++++++++----------------
 adept/kubuntu_upgrader/errordialog.cpp   |  4 +--
 adept/kubuntu_upgrader/errordialog.h     |  2 +-
 adept/kubuntu_upgrader/upgradewizard.cpp |  4 +--
 adept/kubuntu_upgrader/upgradewizard.h   |  2 +-
 adept/libadept/acqprogress.cpp           | 12 ++++----
 adept/libadept/acqprogress.h             | 10 +++----
 adept/libadept/acqprogresswidget.cpp     |  4 +--
 adept/libadept/acqprogresswidget.h       |  2 +-
 adept/libadept/desktoplist.cpp           |  4 +--
 adept/libadept/desktoplist.h             |  2 +-
 adept/libadept/easytagfilter.cpp         |  4 +--
 adept/libadept/easytagfilter.h           |  2 +-
 adept/libadept/extendablelist.cpp        |  8 +++---
 adept/libadept/extendablelist.h          |  4 +--
 adept/libadept/filterlist.cpp            |  4 +--
 adept/libadept/filterlist.h              |  2 +-
 adept/libadept/filterwidget.h            |  4 +--
 adept/libadept/lister.cpp                | 20 ++++++-------
 adept/libadept/lister.h                  |  6 ++--
 adept/libadept/quickfilter.cpp           |  4 +--
 adept/libadept/quickfilter.h             |  2 +-
 adept/libadept/statefilter.cpp           | 38 ++++++++++++-------------
 adept/libadept/statefilter.h             | 48 ++++++++++++++++----------------
 adept/notifier/app.cpp                   |  4 +--
 adept/notifier/app.h                     |  2 +-
 adept/tests/libcapture/tree-test.cpp     | 16 +++++------
 47 files changed, 203 insertions(+), 203 deletions(-)

diff --git a/adept/adept/acqprogress.cpp b/adept/adept/acqprogress.cpp
index ca20dc4..2573191 100644
--- a/adept/adept/acqprogress.cpp
+++ b/adept/adept/acqprogress.cpp
@@ -29,8 +29,8 @@ using namespace std;
 
 namespace adept {
 
-AcqtqStatus::Item::Item (KListView *tqparent, pkgAcquire::ItemDesc &item, bool hit)
-: KListViewItem( tqparent )
+AcqtqStatus::Item::Item (KListView *parent, pkgAcquire::ItemDesc &item, bool hit)
+: KListViewItem( parent )
 {
     m_pbcol = 0;
     m_prog = new ItemProgress( 0, 0 );
@@ -109,8 +109,8 @@ AcqtqStatus::Item *AcqtqStatus::findItem (pkgAcquire::ItemDesc &Itm)
     return m_items[ Itm.Owner->ID - m_idOffset ];
 }
 
-AcqtqStatus::AcqtqStatus(TQWidget *tqparent, const char *name)
-    : KListView (tqparent, name), m_idOffset( 0 ), m_continue( true )
+AcqtqStatus::AcqtqStatus(TQWidget *parent, const char *name)
+    : KListView (parent, name), m_idOffset( 0 ), m_continue( true )
 {
     // m_lastItem = 0;
     addColumn( i18n( "Progress" ) );
@@ -266,8 +266,8 @@ void AcqtqStatus::cancel()
     m_continue = false;
 }
 
-AcqStatusDialog::AcqStatusDialog (TQWidget *tqparent, const char *name, bool modal)
-    : KDialogBase( tqparent, name, modal,
+AcqStatusDialog::AcqStatusDialog (TQWidget *parent, const char *name, bool modal)
+    : KDialogBase( parent, name, modal,
                    u8( "progress dialog (FIXME: waiting for headers, done)" ),
                    Ok|Cancel, Cancel, true )
 {
diff --git a/adept/adept/acqprogress.h b/adept/adept/acqprogress.h
index e6aa258..134bf0a 100644
--- a/adept/adept/acqprogress.h
+++ b/adept/adept/acqprogress.h
@@ -30,8 +30,8 @@ class AcqtqStatus : public KListView, public aptFront::ProgressCallback
 protected:
     class ItemProgress: public KProgress {
     public:
-        ItemProgress( TQWidget *tqparent, const char *name = 0 )
-            : KProgress( tqparent, name ), m_spin( 0 ) {}
+        ItemProgress( TQWidget *parent, const char *name = 0 )
+            : KProgress( parent, name ), m_spin( 0 ) {}
         void settqStatus( const std::string &s,
                         int prog = 0 ) {
             m_status = s;
@@ -62,7 +62,7 @@ protected:
         pkgAcquire::ItemDesc m_item;
 
     public:
-        Item (KListView *tqparent, pkgAcquire::ItemDesc &item,
+        Item (KListView *parent, pkgAcquire::ItemDesc &item,
               bool hit = false);
         virtual ~Item ();
 
@@ -88,7 +88,7 @@ public:
     
     enum tqStatus { StWaiting, StDownloading, StDone };
     
-    AcqtqStatus (TQWidget *tqparent, const char *name);
+    AcqtqStatus (TQWidget *parent, const char *name);
     Item *findItem (pkgAcquire::ItemDesc &Itm);
     
     virtual bool MediaChange (string Media,string Drive);
@@ -121,7 +121,7 @@ protected:
 	aptFront::SharedPtr<AcqtqStatus> m_status;
 public:
     aptFront::SharedPtr<aptFront::ProgressCallback> callback() { return m_status.data(); };
-    AcqStatusDialog (TQWidget *tqparent, const char *name, bool modal);
+    AcqStatusDialog (TQWidget *parent, const char *name, bool modal);
 public slots:
     void statusChange (AcqtqStatus::tqStatus st);
 };
diff --git a/adept/adept/acqprogresswidget.cpp b/adept/adept/acqprogresswidget.cpp
index 73cb09e..a2e9637 100644
--- a/adept/adept/acqprogresswidget.cpp
+++ b/adept/adept/acqprogresswidget.cpp
@@ -7,8 +7,8 @@
 
 using namespace adept;
 
-AcqProgressWidget::AcqProgressWidget( TQWidget *tqparent, const char *name )
-    : AcqProgressWidgetUi( tqparent, name )
+AcqProgressWidget::AcqProgressWidget( TQWidget *parent, const char *name )
+    : AcqProgressWidgetUi( parent, name )
 {
     m_statusRef = m_status;
     m_progress->setTotalSteps( 100 );
diff --git a/adept/adept/acqprogresswidget.h b/adept/adept/acqprogresswidget.h
index faf068a..c5cab30 100644
--- a/adept/adept/acqprogresswidget.h
+++ b/adept/adept/acqprogresswidget.h
@@ -16,7 +16,7 @@ class AcqProgressWidget : public AcqProgressWidgetUi {
     Q_OBJECT
   TQ_OBJECT
 public:
-    AcqProgressWidget (TQWidget *tqparent = 0, const char *name = 0);
+    AcqProgressWidget (TQWidget *parent = 0, const char *name = 0);
     aptFront::SharedPtr<aptFront::ProgressCallback> callback() { return m_statusRef.data(); };
 public slots:
     void statusChange( AcqtqStatus::tqStatus );
diff --git a/adept/adept/application.cpp b/adept/adept/application.cpp
index e40b0eb..57e1265 100644
--- a/adept/adept/application.cpp
+++ b/adept/adept/application.cpp
@@ -31,8 +31,8 @@ using namespace cache;
 #include <tqstringlist.h>
 #define DPKG_FIXER_ARGS TQStringList::split(TQString(" "), TQString("dpkg --configure -a"), false)
 
-DpkgFixer::DpkgFixer(struct Application* tqparent)
-  : m_parent(tqparent)
+DpkgFixer::DpkgFixer(struct Application* parent)
+  : m_parent(parent)
 {
   m_fixer = 0;
   m_waiter = 0;
diff --git a/adept/adept/changelog.h b/adept/adept/changelog.h
index 764ad28..5ed8601 100644
--- a/adept/adept/changelog.h
+++ b/adept/adept/changelog.h
@@ -29,7 +29,7 @@ namespace adept {
 
     // Give me the changelog's URL
     TQString changelogUrl();
-    void setParent(entity::Package tqparent) { m_pkg = tqparent; }
+    void setParent(entity::Package parent) { m_pkg = parent; }
   signals:
     void changelogNeeded();
     void changelogReady(TQString content);
diff --git a/adept/adept/desktoplist.cpp b/adept/adept/desktoplist.cpp
index 8e8cb8a..c522ff2 100644
--- a/adept/adept/desktoplist.cpp
+++ b/adept/adept/desktoplist.cpp
@@ -138,8 +138,8 @@ void DesktopEntry::notifyPostChange() {
     m_check->blockSignals( false );
 }
 
-DesktopList::DesktopList( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ), m_polishing( 0 ), m_displayCheckboxes( true )
+DesktopList::DesktopList( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ), m_polishing( 0 ), m_displayCheckboxes( true )
 {
     observeComponent< component::State >();
     addColumn( i18n( "Application" ) );
diff --git a/adept/adept/desktoplist.h b/adept/adept/desktoplist.h
index f072869..0469a25 100644
--- a/adept/adept/desktoplist.h
+++ b/adept/adept/desktoplist.h
@@ -27,7 +27,7 @@ class DesktopList : public ExtendableList, public cache::Observer
   TQ_OBJECT
 public:
     typedef utils::Range< entity::Desktop > Range;
-    DesktopList( TQWidget *tqparent = 0, const char *name = 0 );
+    DesktopList( TQWidget *parent = 0, const char *name = 0 );
     void insertRange( Range );
     TQPixmap emptyIcon() { return m_emptyIcon; }
     void polishing();
diff --git a/adept/adept/easytagfilter.cpp b/adept/adept/easytagfilter.cpp
index d651a04..47f0a91 100644
--- a/adept/adept/easytagfilter.cpp
+++ b/adept/adept/easytagfilter.cpp
@@ -18,8 +18,8 @@ static void fillCombo( TQComboBox *c, const std::string f ) {
     }
 }
 
-EasyTagFilterWidget::EasyTagFilterWidget( TQWidget *tqparent, const char *name )
-    : EasyTagFilterUi( tqparent, name )
+EasyTagFilterWidget::EasyTagFilterWidget( TQWidget *parent, const char *name )
+    : EasyTagFilterUi( parent, name )
 {
     fillCombo( m_use, "use" );
     fillCombo( m_interface, "interface" );
diff --git a/adept/adept/easytagfilter.h b/adept/adept/easytagfilter.h
index dbee168..009acc7 100644
--- a/adept/adept/easytagfilter.h
+++ b/adept/adept/easytagfilter.h
@@ -82,7 +82,7 @@ class EasyTagFilterWidget : public EasyTagFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    EasyTagFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    EasyTagFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/adept/extendablelist.cpp b/adept/adept/extendablelist.cpp
index a82699e..199b4d8 100644
--- a/adept/adept/extendablelist.cpp
+++ b/adept/adept/extendablelist.cpp
@@ -77,7 +77,7 @@ int ExtendableList::extenderOffset( ExtendableItem *i )
             x += i->pixmap( m_toggleColumn )->width();
         if ( rootIsDecorated() )
             x += treeStepSize();
-        if ( i->tqparent() )
+        if ( i->parent() )
             x += treeStepSize();
     }
 
@@ -92,7 +92,7 @@ void ExtendableList::updateExtender( ExtendableItem *i )
     // get at it (since setContentsPos in TQListView calls it
     setContentsPos( contentsX(), contentsY() );
 
-    if ( !i->isVisible() || ( i->tqparent() && !i->tqparent()->isOpen() ) ) {
+    if ( !i->isVisible() || ( i->parent() && !i->parent()->isOpen() ) ) {
         kdDebug() << "hiding invisible item's extender" << endl;
         i->hideExtender();
         return;
@@ -257,8 +257,8 @@ void ExtendableItem::updateIcon() {
     setUpdatedIcon(p);
 
     // umm hack
-    if ( dynamic_cast< ExtendableItem * >( tqparent() ) )
-        dynamic_cast< ExtendableItem * >( tqparent() )->updateIcon();
+    if ( dynamic_cast< ExtendableItem * >( parent() ) )
+        dynamic_cast< ExtendableItem * >( parent() )->updateIcon();
 }
 
 
diff --git a/adept/adept/extendablelist.h b/adept/adept/extendablelist.h
index e8e6cdf..3bad5ec 100644
--- a/adept/adept/extendablelist.h
+++ b/adept/adept/extendablelist.h
@@ -127,8 +127,8 @@ class ItemExtender : public TQWidget {
     TQ_OBJECT
 public:
     // ItemExtender( ExtendableItem *item );
-    ItemExtender( TQWidget *tqparent, const char *n )
-        : TQWidget( tqparent, n ), m_item( 0 )
+    ItemExtender( TQWidget *parent, const char *n )
+        : TQWidget( parent, n ), m_item( 0 )
         {}
 
     virtual void setItem( ExtendableItem *i ) {
diff --git a/adept/adept/filterlist.cpp b/adept/adept/filterlist.cpp
index 864f332..9e6c607 100644
--- a/adept/adept/filterlist.cpp
+++ b/adept/adept/filterlist.cpp
@@ -49,8 +49,8 @@ void PredicateInterface::widgetsChanged() {
     downcast< FilterItem >( item() ).setPredicate( m_pred );
 }
 
-FilterList::FilterList( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ),
+FilterList::FilterList( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ),
       m_pred( predicate::True< entity::Entity >() ),
       m_hidden( predicate::True< entity::Entity >() )
 {
diff --git a/adept/adept/filterlist.h b/adept/adept/filterlist.h
index a8a6acf..7aa52bd 100644
--- a/adept/adept/filterlist.h
+++ b/adept/adept/filterlist.h
@@ -75,7 +75,7 @@ public:
     friend class FilterItem;
     typedef predicate::Predicate< entity::Entity > Predicate;
     // typedef std::map< KListViewItem *, Predicate > Map;
-    FilterList( TQWidget *tqparent = 0, const char *name = 0 );
+    FilterList( TQWidget *parent = 0, const char *name = 0 );
     typedef predicate::And< entity::Entity > And;
     void appendPredicate( Predicate p );
     void plugLister( Lister *l );
diff --git a/adept/adept/filterwidget.h b/adept/adept/filterwidget.h
index ba7141e..353daba 100644
--- a/adept/adept/filterwidget.h
+++ b/adept/adept/filterwidget.h
@@ -19,8 +19,8 @@ class FilterWidget : public TQWidget
     Q_OBJECT
   TQ_OBJECT
 public:
-    FilterWidget( TQWidget *tqparent = 0, const char *n = 0 )
-        : TQWidget( tqparent, n ) {}
+    FilterWidget( TQWidget *parent = 0, const char *n = 0 )
+        : TQWidget( parent, n ) {}
     virtual ListerPredicate predicate() = 0;
     void connectLister( Lister *l );
 protected slots:
diff --git a/adept/adept/lister.h b/adept/adept/lister.h
index 3a6c66e..a281fb4 100644
--- a/adept/adept/lister.h
+++ b/adept/adept/lister.h
@@ -74,7 +74,7 @@ public:
         virtual Range listerRange() = 0;
     };
 
-    Lister (TQWidget *tqparent = 0, const char *name = 0);
+    Lister (TQWidget *parent = 0, const char *name = 0);
     ~Lister();
     void setSource();
     virtual void notifyPostChange( component::Base * );
@@ -128,7 +128,7 @@ protected:
         int time;
         int items;
         ListerItem *last;
-        ListerItem *tqparent;
+        ListerItem *parent;
     };
 
     bool cancelRebuild();
@@ -162,9 +162,9 @@ protected:
 
 class ListerItemTooltip : public TQToolTip {
 public:
-  ListerItemTooltip(const Lister* tqparent) :
-    TQToolTip(tqparent->viewport(),0),
-    m_parent(tqparent) {};
+  ListerItemTooltip(const Lister* parent) :
+    TQToolTip(parent->viewport(),0),
+    m_parent(parent) {};
 
 protected:
   const Lister* m_parent;
@@ -176,7 +176,7 @@ class ListerItemExtender : public ListerItemExtenderUi,
     Q_OBJECT
   TQ_OBJECT
 public:
-    ListerItemExtender( TQWidget *tqparent = 0, const char * n = 0 );
+    ListerItemExtender( TQWidget *parent = 0, const char * n = 0 );
     ~ListerItemExtender();
     virtual void resize( int w, int h );
     void setItem( ExtendableItem *i );
diff --git a/adept/adept/quickfilter.cpp b/adept/adept/quickfilter.cpp
index 3e99a58..7300727 100644
--- a/adept/adept/quickfilter.cpp
+++ b/adept/adept/quickfilter.cpp
@@ -11,8 +11,8 @@
 using namespace aptFront;
 using namespace adept;
 
-QuickFilterWidget::QuickFilterWidget( TQWidget *tqparent, const char *name )
-    : QuickFilterUi( tqparent, name )
+QuickFilterWidget::QuickFilterWidget( TQWidget *parent, const char *name )
+    : QuickFilterUi( parent, name )
 {
     setFocusProxy( m_match );
     connect( m_match, TQT_SIGNAL( textChanged( const TQString & ) ),
diff --git a/adept/adept/quickfilter.h b/adept/adept/quickfilter.h
index 615454d..4b72300 100644
--- a/adept/adept/quickfilter.h
+++ b/adept/adept/quickfilter.h
@@ -104,7 +104,7 @@ class QuickFilterWidget : public QuickFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    QuickFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    QuickFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/adept/statefilter.cpp b/adept/adept/statefilter.cpp
index 46913da..cd4f6bb 100644
--- a/adept/adept/statefilter.cpp
+++ b/adept/adept/statefilter.cpp
@@ -9,8 +9,8 @@
 using namespace aptFront;
 using namespace adept;
 
-StateFilterWidget::StateFilterWidget( TQWidget *tqparent, const char *name )
-    : StateFilterUi( tqparent, name )
+StateFilterWidget::StateFilterWidget( TQWidget *parent, const char *name )
+    : StateFilterUi( parent, name )
 {
     TQObjectList *chld = queryList( TQCHECKBOX_OBJECT_NAME_STRING );
     TQObjectListIt it( *chld );
@@ -24,17 +24,17 @@ StateFilterWidget::StateFilterWidget( TQWidget *tqparent, const char *name )
 StateFilterWidget::Predicate StateFilterWidget::predicate()
 {
     typedef StateFilter< entity::Package > F;
-    unsigned tqmask = 0;
-    if (m_installed->isChecked()) tqmask |= F::Installed;
-    if (m_notInstalled->isChecked()) tqmask |= F::NotInstalled;
-    if (m_upgradable->isChecked()) tqmask |= F::Upgradable;
-    if (m_keep->isChecked()) tqmask |= F::Keep;
-    if (m_install->isChecked()) tqmask |= F::Install;
-    if (m_remove->isChecked()) tqmask |= F::Remove;
-    if (m_upgrade->isChecked()) tqmask |= F::Upgrade;
+    unsigned mask = 0;
+    if (m_installed->isChecked()) mask |= F::Installed;
+    if (m_notInstalled->isChecked()) mask |= F::NotInstalled;
+    if (m_upgradable->isChecked()) mask |= F::Upgradable;
+    if (m_keep->isChecked()) mask |= F::Keep;
+    if (m_install->isChecked()) mask |= F::Install;
+    if (m_remove->isChecked()) mask |= F::Remove;
+    if (m_upgrade->isChecked()) mask |= F::Upgrade;
 
     StateFilter< entity::Package > f;
-    f.setMask( tqmask );
+    f.setMask( mask );
     return predicate::adapt< entity::Entity >( f );
 }
 
@@ -48,13 +48,13 @@ void StateFilterWidget::predicateChanged()
 {
     typedef StateFilter< entity::Package > F;
     F f = downcast< F >( m_pred );
-    unsigned tqmask = f.tqmask();
-    blockedSet( m_installed, tqmask & F::Installed );
-    blockedSet( m_notInstalled, tqmask & F::NotInstalled );
-    blockedSet( m_upgradable, tqmask & F::Upgradable );
-    blockedSet( m_keep, tqmask & F::Keep );
-    blockedSet( m_install, tqmask & F::Install );
-    blockedSet( m_upgrade, tqmask & F::Upgrade );
-    blockedSet( m_remove, tqmask & F::Remove );
+    unsigned mask = f.mask();
+    blockedSet( m_installed, mask & F::Installed );
+    blockedSet( m_notInstalled, mask & F::NotInstalled );
+    blockedSet( m_upgradable, mask & F::Upgradable );
+    blockedSet( m_keep, mask & F::Keep );
+    blockedSet( m_install, mask & F::Install );
+    blockedSet( m_upgrade, mask & F::Upgrade );
+    blockedSet( m_remove, mask & F::Remove );
 }
 
diff --git a/adept/adept/statefilter.h b/adept/adept/statefilter.h
index ddea502..e4e028e 100644
--- a/adept/adept/statefilter.h
+++ b/adept/adept/statefilter.h
@@ -36,7 +36,7 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
                 Upgrade = 1 << 6 };
 
     StateFilter()
-        : m_tqmask( 0xff ) {
+        : m_mask( 0xff ) {
         setupPredicate();
     }
 
@@ -44,21 +44,21 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         predicate::Predicate< T >
             p0 = not predicate::True< T >(),
             p1 = not predicate::True< T >();
-        if (m_tqmask & Installed)
+        if (m_mask & Installed)
             p0 = p0 or (predicate::Factory< T >::member( &T::isInstalled )
                         and not predicate::Factory< T >::member( &T::isUpgradable ) );
-        if (m_tqmask & NotInstalled)
+        if (m_mask & NotInstalled)
             p0 = p0 or not predicate::Factory< T >::member( &T::isInstalled );
-        if (m_tqmask & Upgradable)
+        if (m_mask & Upgradable)
             p0 = p0 or predicate::Factory< T >::member( &T::isUpgradable );
         
-        if (m_tqmask & Install)
+        if (m_mask & Install)
             p1 = p1 or predicate::Factory< T >::member( &T::markedNewInstall );
-        if (m_tqmask & Remove)
+        if (m_mask & Remove)
             p1 = p1 or predicate::Factory< T >::member( &T::markedRemove );
-        if (m_tqmask & Keep)
+        if (m_mask & Keep)
             p1 = p1 or predicate::Factory< T >::member( &T::markedKeep );
-        if (m_tqmask & Upgrade)
+        if (m_mask & Upgrade)
             p1 = p1 or predicate::Factory< T >::member( &T::markedUpgrade );
         
         m_op = p0 and p1;
@@ -68,31 +68,31 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         std::ostringstream s;
         std::vector< std::string > r;
         s << "State filter: ";
-        if (m_tqmask & Installed && m_tqmask & NotInstalled && m_tqmask & Upgradable)
+        if (m_mask & Installed && m_mask & NotInstalled && m_mask & Upgradable)
             r.push_back( "Any State" );
         else {
-            if (m_tqmask & Installed)
+            if (m_mask & Installed)
                 r.push_back( i18n( "Installed" ).ascii() );
-            if (m_tqmask & NotInstalled)
+            if (m_mask & NotInstalled)
                 r.push_back( i18n( "Not Installed" ).ascii() );
-            if (m_tqmask & Upgradable)
+            if (m_mask & Upgradable)
                 r.push_back( i18n( "Upgradable" ).ascii() );
         }
         std::copy( r.begin(), r.end(),
                    std::ostream_iterator< std::string >( s, " " ) );
         s << "; ";
         r.clear();
-        if (m_tqmask & Install && m_tqmask & Remove
-            && m_tqmask & Keep && m_tqmask & Upgrade)
+        if (m_mask & Install && m_mask & Remove
+            && m_mask & Keep && m_mask & Upgrade)
             r.push_back( i18n( "Any Action" ).ascii() );
         else {
-            if (m_tqmask & Install)
+            if (m_mask & Install)
                 r.push_back( i18n( "Install" ).ascii() );
-            if (m_tqmask & Remove)
+            if (m_mask & Remove)
                 r.push_back( i18n( "Remove" ).ascii() );
-            if (m_tqmask & Keep)
+            if (m_mask & Keep)
                 r.push_back( i18n( "Keep" ).ascii() );
-            if (m_tqmask & Upgrade)
+            if (m_mask & Upgrade)
                 r.push_back( i18n( "Upgrade" ).ascii() );
         }
         std::copy( r.begin(), r.end(),
@@ -100,12 +100,12 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         return s.str();
     }
 
-    unsigned tqmask() const {
-        return m_tqmask;
+    unsigned mask() const {
+        return m_mask;
     }
 
     void setMask( unsigned m ) {
-        m_tqmask = m;
+        m_mask = m;
         setupPredicate();
     }
 
@@ -120,12 +120,12 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
     }
 
     virtual void reset() {
-        m_tqmask = 0xff;
+        m_mask = 0xff;
         setupPredicate();
     }
 
 protected:
-    unsigned m_tqmask;
+    unsigned m_mask;
     predicate::Predicate< T > m_op;
 };
 
@@ -134,7 +134,7 @@ class StateFilterWidget : public StateFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    StateFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    StateFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/kubuntu_upgrader/errordialog.cpp b/adept/kubuntu_upgrader/errordialog.cpp
index 10a988d..0e2ba91 100644
--- a/adept/kubuntu_upgrader/errordialog.cpp
+++ b/adept/kubuntu_upgrader/errordialog.cpp
@@ -22,8 +22,8 @@
 
 #include "errordialog.h"
 
-ErrorDialog::ErrorDialog(TQWidget* tqparent, TQString error_text, const char* name, bool modal, WFlags fl )
-    : ErrorDialogDlg(tqparent,name, modal,fl)
+ErrorDialog::ErrorDialog(TQWidget* parent, TQString error_text, const char* name, bool modal, WFlags fl )
+    : ErrorDialogDlg(parent,name, modal,fl)
 {
 	errorLabel->setText( error_text );
 }
diff --git a/adept/kubuntu_upgrader/errordialog.h b/adept/kubuntu_upgrader/errordialog.h
index 0872f61..fc03d33 100644
--- a/adept/kubuntu_upgrader/errordialog.h
+++ b/adept/kubuntu_upgrader/errordialog.h
@@ -31,7 +31,7 @@ class ErrorDialog : public ErrorDialogDlg
   TQ_OBJECT
 
 public:
-  ErrorDialog(TQWidget* tqparent = 0, TQString error_text = TQString(), const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  ErrorDialog(TQWidget* parent = 0, TQString error_text = TQString(), const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
   ~ErrorDialog();
   /*$PUBLIC_FUNCTIONS$*/
 
diff --git a/adept/kubuntu_upgrader/upgradewizard.cpp b/adept/kubuntu_upgrader/upgradewizard.cpp
index b40db8b..c715d90 100644
--- a/adept/kubuntu_upgrader/upgradewizard.cpp
+++ b/adept/kubuntu_upgrader/upgradewizard.cpp
@@ -74,8 +74,8 @@ DistroEntry::~DistroEntry() {
 	free( upgrade_tool_sig_url );
 }
 
-UpgradeWizard::UpgradeWizard(TQWidget* tqparent, const char* name, bool modal, WFlags fl)
-    : UpgradeWizardDlg(tqparent,name, modal,fl)
+UpgradeWizard::UpgradeWizard(TQWidget* parent, const char* name, bool modal, WFlags fl)
+    : UpgradeWizardDlg(parent,name, modal,fl)
 {	
 	err_dlg = NULL;
 
diff --git a/adept/kubuntu_upgrader/upgradewizard.h b/adept/kubuntu_upgrader/upgradewizard.h
index 3597de8..8accc44 100644
--- a/adept/kubuntu_upgrader/upgradewizard.h
+++ b/adept/kubuntu_upgrader/upgradewizard.h
@@ -53,7 +53,7 @@ class UpgradeWizard : public UpgradeWizardDlg
   TQ_OBJECT
 
 public:
-  UpgradeWizard(TQWidget* tqparent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+  UpgradeWizard(TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
   ~UpgradeWizard();
 
   /*$PUBLIC_FUNCTIONS$*/
diff --git a/adept/libadept/acqprogress.cpp b/adept/libadept/acqprogress.cpp
index 21e4046..2f715c6 100644
--- a/adept/libadept/acqprogress.cpp
+++ b/adept/libadept/acqprogress.cpp
@@ -29,8 +29,8 @@ using namespace std;
 
 namespace adept {
 
-AcqtqStatus::Item::Item (KListView *tqparent, pkgAcquire::ItemDesc &item, bool hit)
-: KListViewItem( tqparent )
+AcqtqStatus::Item::Item (KListView *parent, pkgAcquire::ItemDesc &item, bool hit)
+: KListViewItem( parent )
 {
     m_pbcol = 0;
     m_prog = new ItemProgress( 0, 0 );
@@ -109,8 +109,8 @@ AcqtqStatus::Item *AcqtqStatus::findItem (pkgAcquire::ItemDesc &Itm)
     return m_items[ Itm.Owner->ID - m_idOffset ];
 }
 
-AcqtqStatus::AcqtqStatus(TQWidget *tqparent, const char *name)
-    : KListView (tqparent, name), m_idOffset( 0 ), m_continue( true )
+AcqtqStatus::AcqtqStatus(TQWidget *parent, const char *name)
+    : KListView (parent, name), m_idOffset( 0 ), m_continue( true )
 {
     // m_lastItem = 0;
     addColumn( i18n( "Progress" ) );
@@ -266,8 +266,8 @@ void AcqtqStatus::cancel()
     m_continue = false;
 }
 
-AcqStatusDialog::AcqStatusDialog (TQWidget *tqparent, const char *name, bool modal)
-    : KDialogBase( tqparent, name, modal,
+AcqStatusDialog::AcqStatusDialog (TQWidget *parent, const char *name, bool modal)
+    : KDialogBase( parent, name, modal,
                    u8( "progress dialog (FIXME: waiting for headers, done)" ),
                    Ok|Cancel, Cancel, true )
 {
diff --git a/adept/libadept/acqprogress.h b/adept/libadept/acqprogress.h
index e6aa258..134bf0a 100644
--- a/adept/libadept/acqprogress.h
+++ b/adept/libadept/acqprogress.h
@@ -30,8 +30,8 @@ class AcqtqStatus : public KListView, public aptFront::ProgressCallback
 protected:
     class ItemProgress: public KProgress {
     public:
-        ItemProgress( TQWidget *tqparent, const char *name = 0 )
-            : KProgress( tqparent, name ), m_spin( 0 ) {}
+        ItemProgress( TQWidget *parent, const char *name = 0 )
+            : KProgress( parent, name ), m_spin( 0 ) {}
         void settqStatus( const std::string &s,
                         int prog = 0 ) {
             m_status = s;
@@ -62,7 +62,7 @@ protected:
         pkgAcquire::ItemDesc m_item;
 
     public:
-        Item (KListView *tqparent, pkgAcquire::ItemDesc &item,
+        Item (KListView *parent, pkgAcquire::ItemDesc &item,
               bool hit = false);
         virtual ~Item ();
 
@@ -88,7 +88,7 @@ public:
     
     enum tqStatus { StWaiting, StDownloading, StDone };
     
-    AcqtqStatus (TQWidget *tqparent, const char *name);
+    AcqtqStatus (TQWidget *parent, const char *name);
     Item *findItem (pkgAcquire::ItemDesc &Itm);
     
     virtual bool MediaChange (string Media,string Drive);
@@ -121,7 +121,7 @@ protected:
 	aptFront::SharedPtr<AcqtqStatus> m_status;
 public:
     aptFront::SharedPtr<aptFront::ProgressCallback> callback() { return m_status.data(); };
-    AcqStatusDialog (TQWidget *tqparent, const char *name, bool modal);
+    AcqStatusDialog (TQWidget *parent, const char *name, bool modal);
 public slots:
     void statusChange (AcqtqStatus::tqStatus st);
 };
diff --git a/adept/libadept/acqprogresswidget.cpp b/adept/libadept/acqprogresswidget.cpp
index 73cb09e..a2e9637 100644
--- a/adept/libadept/acqprogresswidget.cpp
+++ b/adept/libadept/acqprogresswidget.cpp
@@ -7,8 +7,8 @@
 
 using namespace adept;
 
-AcqProgressWidget::AcqProgressWidget( TQWidget *tqparent, const char *name )
-    : AcqProgressWidgetUi( tqparent, name )
+AcqProgressWidget::AcqProgressWidget( TQWidget *parent, const char *name )
+    : AcqProgressWidgetUi( parent, name )
 {
     m_statusRef = m_status;
     m_progress->setTotalSteps( 100 );
diff --git a/adept/libadept/acqprogresswidget.h b/adept/libadept/acqprogresswidget.h
index faf068a..c5cab30 100644
--- a/adept/libadept/acqprogresswidget.h
+++ b/adept/libadept/acqprogresswidget.h
@@ -16,7 +16,7 @@ class AcqProgressWidget : public AcqProgressWidgetUi {
     Q_OBJECT
   TQ_OBJECT
 public:
-    AcqProgressWidget (TQWidget *tqparent = 0, const char *name = 0);
+    AcqProgressWidget (TQWidget *parent = 0, const char *name = 0);
     aptFront::SharedPtr<aptFront::ProgressCallback> callback() { return m_statusRef.data(); };
 public slots:
     void statusChange( AcqtqStatus::tqStatus );
diff --git a/adept/libadept/desktoplist.cpp b/adept/libadept/desktoplist.cpp
index 8e8cb8a..c522ff2 100644
--- a/adept/libadept/desktoplist.cpp
+++ b/adept/libadept/desktoplist.cpp
@@ -138,8 +138,8 @@ void DesktopEntry::notifyPostChange() {
     m_check->blockSignals( false );
 }
 
-DesktopList::DesktopList( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ), m_polishing( 0 ), m_displayCheckboxes( true )
+DesktopList::DesktopList( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ), m_polishing( 0 ), m_displayCheckboxes( true )
 {
     observeComponent< component::State >();
     addColumn( i18n( "Application" ) );
diff --git a/adept/libadept/desktoplist.h b/adept/libadept/desktoplist.h
index f072869..0469a25 100644
--- a/adept/libadept/desktoplist.h
+++ b/adept/libadept/desktoplist.h
@@ -27,7 +27,7 @@ class DesktopList : public ExtendableList, public cache::Observer
   TQ_OBJECT
 public:
     typedef utils::Range< entity::Desktop > Range;
-    DesktopList( TQWidget *tqparent = 0, const char *name = 0 );
+    DesktopList( TQWidget *parent = 0, const char *name = 0 );
     void insertRange( Range );
     TQPixmap emptyIcon() { return m_emptyIcon; }
     void polishing();
diff --git a/adept/libadept/easytagfilter.cpp b/adept/libadept/easytagfilter.cpp
index be44b76..55a1925 100644
--- a/adept/libadept/easytagfilter.cpp
+++ b/adept/libadept/easytagfilter.cpp
@@ -19,8 +19,8 @@ static void fillCombo( TQComboBox *c, const std::string f ) {
     }
 }
 
-EasyTagFilterWidget::EasyTagFilterWidget( TQWidget *tqparent, const char *name )
-    : EasyTagFilterUi( tqparent, name )
+EasyTagFilterWidget::EasyTagFilterWidget( TQWidget *parent, const char *name )
+    : EasyTagFilterUi( parent, name )
 {
     fillCombo( m_use, "use" );
     fillCombo( m_interface, "interface" );
diff --git a/adept/libadept/easytagfilter.h b/adept/libadept/easytagfilter.h
index a7ed4f2..e2f6165 100644
--- a/adept/libadept/easytagfilter.h
+++ b/adept/libadept/easytagfilter.h
@@ -82,7 +82,7 @@ class EasyTagFilterWidget : public EasyTagFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    EasyTagFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    EasyTagFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/libadept/extendablelist.cpp b/adept/libadept/extendablelist.cpp
index 215c155..c97fa0f 100644
--- a/adept/libadept/extendablelist.cpp
+++ b/adept/libadept/extendablelist.cpp
@@ -73,7 +73,7 @@ int ExtendableList::extenderOffset( ExtendableItem *i )
             x += i->pixmap( m_toggleColumn )->width();
         if ( rootIsDecorated() )
             x += treeStepSize();
-        if ( i->tqparent() )
+        if ( i->parent() )
             x += treeStepSize();
     }
 
@@ -88,7 +88,7 @@ void ExtendableList::updateExtender( ExtendableItem *i )
     // get at it (since setContentsPos in TQListView calls it
     setContentsPos( contentsX(), contentsY() );
 
-    if ( !i->isVisible() || ( i->tqparent() && !i->tqparent()->isOpen() ) ) {
+    if ( !i->isVisible() || ( i->parent() && !i->parent()->isOpen() ) ) {
         kdDebug() << "hiding invisible item's extender" << endl;
         i->hideExtender();
         return;
@@ -250,8 +250,8 @@ void ExtendableItem::updateIcon() {
     setPixmap( list()->toggleColumn(), p );
 
     // umm hack
-    if ( dynamic_cast< ExtendableItem * >( tqparent() ) )
-        dynamic_cast< ExtendableItem * >( tqparent() )->updateIcon();
+    if ( dynamic_cast< ExtendableItem * >( parent() ) )
+        dynamic_cast< ExtendableItem * >( parent() )->updateIcon();
 }
 
 
diff --git a/adept/libadept/extendablelist.h b/adept/libadept/extendablelist.h
index 8836fbe..b90e86f 100644
--- a/adept/libadept/extendablelist.h
+++ b/adept/libadept/extendablelist.h
@@ -126,8 +126,8 @@ class ItemExtender : public TQWidget {
   TQ_OBJECT
 public:
     // ItemExtender( ExtendableItem *item );
-    ItemExtender( TQWidget *tqparent, const char *n )
-        : TQWidget( tqparent, n ), m_item( 0 )
+    ItemExtender( TQWidget *parent, const char *n )
+        : TQWidget( parent, n ), m_item( 0 )
         {}
 
     virtual void setItem( ExtendableItem *i ) {
diff --git a/adept/libadept/filterlist.cpp b/adept/libadept/filterlist.cpp
index fa054e1..207a5db 100644
--- a/adept/libadept/filterlist.cpp
+++ b/adept/libadept/filterlist.cpp
@@ -48,8 +48,8 @@ void PredicateInterface::widgetsChanged() {
     downcast< FilterItem >( item() ).setPredicate( m_pred );
 }
 
-FilterList::FilterList( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ),
+FilterList::FilterList( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ),
       m_pred( predicate::True< entity::Entity >() ),
       m_hidden( predicate::True< entity::Entity >() )
 {
diff --git a/adept/libadept/filterlist.h b/adept/libadept/filterlist.h
index bf95c49..4101a81 100644
--- a/adept/libadept/filterlist.h
+++ b/adept/libadept/filterlist.h
@@ -68,7 +68,7 @@ public:
     friend class FilterItem;
     typedef predicate::Predicate< entity::Entity > Predicate;
     // typedef std::map< KListViewItem *, Predicate > Map;
-    FilterList( TQWidget *tqparent = 0, const char *name = 0 );
+    FilterList( TQWidget *parent = 0, const char *name = 0 );
     typedef predicate::And< entity::Entity > And;
     void appendPredicate( Predicate p );
     void plugLister( Lister *l );
diff --git a/adept/libadept/filterwidget.h b/adept/libadept/filterwidget.h
index ba7141e..353daba 100644
--- a/adept/libadept/filterwidget.h
+++ b/adept/libadept/filterwidget.h
@@ -19,8 +19,8 @@ class FilterWidget : public TQWidget
     Q_OBJECT
   TQ_OBJECT
 public:
-    FilterWidget( TQWidget *tqparent = 0, const char *n = 0 )
-        : TQWidget( tqparent, n ) {}
+    FilterWidget( TQWidget *parent = 0, const char *n = 0 )
+        : TQWidget( parent, n ) {}
     virtual ListerPredicate predicate() = 0;
     void connectLister( Lister *l );
 protected slots:
diff --git a/adept/libadept/lister.h b/adept/libadept/lister.h
index 1bac3f8..d1acc91 100644
--- a/adept/libadept/lister.h
+++ b/adept/libadept/lister.h
@@ -56,7 +56,7 @@ public:
         virtual Range listerRange() = 0;
     };
 
-    Lister (TQWidget *tqparent = 0, const char *name = 0);
+    Lister (TQWidget *parent = 0, const char *name = 0);
     ~Lister();
     void setSource();
     virtual void notifyPostChange( component::Base * );
@@ -110,7 +110,7 @@ protected:
         int time;
         int items;
         ListerItem *last;
-        ListerItem *tqparent;
+        ListerItem *parent;
     };
 
     bool cancelRebuild();
@@ -146,7 +146,7 @@ class ListerItemExtender : public ListerItemExtenderUi,
     Q_OBJECT
   TQ_OBJECT
 public:
-    ListerItemExtender( TQWidget *tqparent = 0, const char * n = 0 );
+    ListerItemExtender( TQWidget *parent = 0, const char * n = 0 );
     ~ListerItemExtender();
     virtual void resize( int w, int h );
     void setItem( ExtendableItem *i );
diff --git a/adept/libadept/quickfilter.cpp b/adept/libadept/quickfilter.cpp
index 3e99a58..7300727 100644
--- a/adept/libadept/quickfilter.cpp
+++ b/adept/libadept/quickfilter.cpp
@@ -11,8 +11,8 @@
 using namespace aptFront;
 using namespace adept;
 
-QuickFilterWidget::QuickFilterWidget( TQWidget *tqparent, const char *name )
-    : QuickFilterUi( tqparent, name )
+QuickFilterWidget::QuickFilterWidget( TQWidget *parent, const char *name )
+    : QuickFilterUi( parent, name )
 {
     setFocusProxy( m_match );
     connect( m_match, TQT_SIGNAL( textChanged( const TQString & ) ),
diff --git a/adept/libadept/quickfilter.h b/adept/libadept/quickfilter.h
index 615454d..4b72300 100644
--- a/adept/libadept/quickfilter.h
+++ b/adept/libadept/quickfilter.h
@@ -104,7 +104,7 @@ class QuickFilterWidget : public QuickFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    QuickFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    QuickFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/libadept/statefilter.cpp b/adept/libadept/statefilter.cpp
index 46913da..cd4f6bb 100644
--- a/adept/libadept/statefilter.cpp
+++ b/adept/libadept/statefilter.cpp
@@ -9,8 +9,8 @@
 using namespace aptFront;
 using namespace adept;
 
-StateFilterWidget::StateFilterWidget( TQWidget *tqparent, const char *name )
-    : StateFilterUi( tqparent, name )
+StateFilterWidget::StateFilterWidget( TQWidget *parent, const char *name )
+    : StateFilterUi( parent, name )
 {
     TQObjectList *chld = queryList( TQCHECKBOX_OBJECT_NAME_STRING );
     TQObjectListIt it( *chld );
@@ -24,17 +24,17 @@ StateFilterWidget::StateFilterWidget( TQWidget *tqparent, const char *name )
 StateFilterWidget::Predicate StateFilterWidget::predicate()
 {
     typedef StateFilter< entity::Package > F;
-    unsigned tqmask = 0;
-    if (m_installed->isChecked()) tqmask |= F::Installed;
-    if (m_notInstalled->isChecked()) tqmask |= F::NotInstalled;
-    if (m_upgradable->isChecked()) tqmask |= F::Upgradable;
-    if (m_keep->isChecked()) tqmask |= F::Keep;
-    if (m_install->isChecked()) tqmask |= F::Install;
-    if (m_remove->isChecked()) tqmask |= F::Remove;
-    if (m_upgrade->isChecked()) tqmask |= F::Upgrade;
+    unsigned mask = 0;
+    if (m_installed->isChecked()) mask |= F::Installed;
+    if (m_notInstalled->isChecked()) mask |= F::NotInstalled;
+    if (m_upgradable->isChecked()) mask |= F::Upgradable;
+    if (m_keep->isChecked()) mask |= F::Keep;
+    if (m_install->isChecked()) mask |= F::Install;
+    if (m_remove->isChecked()) mask |= F::Remove;
+    if (m_upgrade->isChecked()) mask |= F::Upgrade;
 
     StateFilter< entity::Package > f;
-    f.setMask( tqmask );
+    f.setMask( mask );
     return predicate::adapt< entity::Entity >( f );
 }
 
@@ -48,13 +48,13 @@ void StateFilterWidget::predicateChanged()
 {
     typedef StateFilter< entity::Package > F;
     F f = downcast< F >( m_pred );
-    unsigned tqmask = f.tqmask();
-    blockedSet( m_installed, tqmask & F::Installed );
-    blockedSet( m_notInstalled, tqmask & F::NotInstalled );
-    blockedSet( m_upgradable, tqmask & F::Upgradable );
-    blockedSet( m_keep, tqmask & F::Keep );
-    blockedSet( m_install, tqmask & F::Install );
-    blockedSet( m_upgrade, tqmask & F::Upgrade );
-    blockedSet( m_remove, tqmask & F::Remove );
+    unsigned mask = f.mask();
+    blockedSet( m_installed, mask & F::Installed );
+    blockedSet( m_notInstalled, mask & F::NotInstalled );
+    blockedSet( m_upgradable, mask & F::Upgradable );
+    blockedSet( m_keep, mask & F::Keep );
+    blockedSet( m_install, mask & F::Install );
+    blockedSet( m_upgrade, mask & F::Upgrade );
+    blockedSet( m_remove, mask & F::Remove );
 }
 
diff --git a/adept/libadept/statefilter.h b/adept/libadept/statefilter.h
index e578bd0..cd78904 100644
--- a/adept/libadept/statefilter.h
+++ b/adept/libadept/statefilter.h
@@ -36,7 +36,7 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
                 Upgrade = 1 << 6 };
 
     StateFilter()
-        : m_tqmask( 0xff ) {
+        : m_mask( 0xff ) {
         setupPredicate();
     }
 
@@ -44,21 +44,21 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         predicate::Predicate< T >
             p0 = not predicate::True< T >(),
             p1 = not predicate::True< T >();
-        if (m_tqmask & Installed)
+        if (m_mask & Installed)
             p0 = p0 or (predicate::Factory< T >::member( &T::isInstalled )
                         and not predicate::Factory< T >::member( &T::isUpgradable ) );
-        if (m_tqmask & NotInstalled)
+        if (m_mask & NotInstalled)
             p0 = p0 or not predicate::Factory< T >::member( &T::isInstalled );
-        if (m_tqmask & Upgradable)
+        if (m_mask & Upgradable)
             p0 = p0 or predicate::Factory< T >::member( &T::isUpgradable );
         
-        if (m_tqmask & Install)
+        if (m_mask & Install)
             p1 = p1 or predicate::Factory< T >::member( &T::markedNewInstall );
-        if (m_tqmask & Remove)
+        if (m_mask & Remove)
             p1 = p1 or predicate::Factory< T >::member( &T::markedRemove );
-        if (m_tqmask & Keep)
+        if (m_mask & Keep)
             p1 = p1 or predicate::Factory< T >::member( &T::markedKeep );
-        if (m_tqmask & Upgrade)
+        if (m_mask & Upgrade)
             p1 = p1 or predicate::Factory< T >::member( &T::markedUpgrade );
         
         m_op = p0 and p1;
@@ -68,31 +68,31 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         std::ostringstream s;
         std::vector< std::string > r;
         s << "State filter: ";
-        if (m_tqmask & Installed && m_tqmask & NotInstalled && m_tqmask & Upgradable)
+        if (m_mask & Installed && m_mask & NotInstalled && m_mask & Upgradable)
             r.push_back( "Any State" );
         else {
-            if (m_tqmask & Installed)
+            if (m_mask & Installed)
                 r.push_back( i18n( "Installed" ) );
-            if (m_tqmask & NotInstalled)
+            if (m_mask & NotInstalled)
                 r.push_back( i18n( "Not Installed" ) );
-            if (m_tqmask & Upgradable)
+            if (m_mask & Upgradable)
                 r.push_back( i18n( "Upgradable" ) );
         }
         std::copy( r.begin(), r.end(),
                    std::ostream_iterator< std::string >( s, " " ) );
         s << "; ";
         r.clear();
-        if (m_tqmask & Install && m_tqmask & Remove
-            && m_tqmask & Keep && m_tqmask & Upgrade)
+        if (m_mask & Install && m_mask & Remove
+            && m_mask & Keep && m_mask & Upgrade)
             r.push_back( i18n( "Any Action" ) );
         else {
-            if (m_tqmask & Install)
+            if (m_mask & Install)
                 r.push_back( i18n( "Install" ) );
-            if (m_tqmask & Remove)
+            if (m_mask & Remove)
                 r.push_back( i18n( "Remove" ) );
-            if (m_tqmask & Keep)
+            if (m_mask & Keep)
                 r.push_back( i18n( "Keep" ) );
-            if (m_tqmask & Upgrade)
+            if (m_mask & Upgrade)
                 r.push_back( i18n( "Upgrade" ) );
         }
         std::copy( r.begin(), r.end(),
@@ -100,12 +100,12 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
         return s.str();
     }
 
-    unsigned tqmask() const {
-        return m_tqmask;
+    unsigned mask() const {
+        return m_mask;
     }
 
     void setMask( unsigned m ) {
-        m_tqmask = m;
+        m_mask = m;
         setupPredicate();
     }
 
@@ -120,12 +120,12 @@ struct StateFilter : predicate::Implementation< T, StateFilter< T > >,
     }
 
     virtual void reset() {
-        m_tqmask = 0xff;
+        m_mask = 0xff;
         setupPredicate();
     }
 
 protected:
-    unsigned m_tqmask;
+    unsigned m_mask;
     predicate::Predicate< T > m_op;
 };
 
@@ -134,7 +134,7 @@ class StateFilterWidget : public StateFilterUi
     Q_OBJECT
   TQ_OBJECT
 public:
-    StateFilterWidget( TQWidget *tqparent, const char *name = 0 );
+    StateFilterWidget( TQWidget *parent, const char *name = 0 );
     virtual Predicate predicate();
 public slots:
     void predicateChanged();
diff --git a/adept/notifier/app.cpp b/adept/notifier/app.cpp
index 54770bc..f6ca90f 100644
--- a/adept/notifier/app.cpp
+++ b/adept/notifier/app.cpp
@@ -33,8 +33,8 @@ using namespace cache;
 using namespace utils;
 using namespace adept;
 
-TrayWindow::TrayWindow(TQWidget *tqparent, const char *name)
-    : KSystemTray(tqparent, name), m_updates( 0 )
+TrayWindow::TrayWindow(TQWidget *parent, const char *name)
+    : KSystemTray(parent, name), m_updates( 0 )
 {
     setAvailableUpdates( m_updates );
     // actionCollection()->remove( actionCollection()->action( "quit" ) );
diff --git a/adept/notifier/app.h b/adept/notifier/app.h
index 7015647..01e8f79 100644
--- a/adept/notifier/app.h
+++ b/adept/notifier/app.h
@@ -17,7 +17,7 @@ class TrayWindow : public KSystemTray
     Q_OBJECT
   TQ_OBJECT
 public:
-    TrayWindow(TQWidget *tqparent=0, const char *name=0);
+    TrayWindow(TQWidget *parent=0, const char *name=0);
 	void setAvailableUpdates( int n );
     int updates() { return m_updates; }
 	void contextMenuAboutToShow ( KPopupMenu * );
diff --git a/adept/tests/libcapture/tree-test.cpp b/adept/tests/libcapture/tree-test.cpp
index 6cb8a38..0e2f8d5 100644
--- a/adept/tests/libcapture/tree-test.cpp
+++ b/adept/tests/libcapture/tree-test.cpp
@@ -21,15 +21,15 @@ namespace tut {
     class STF: public TreeFactory
     {
         public:
-            TreePkgNode *makePkgNode (TreeNode *tqparent, pkgCache::PkgIterator P)
-            { return new TreePkgNode (tqparent, P); }
-            TreeBranchNode *makeBranchNode (TreeNode *tqparent, string id, string name)
-            { return new TreeBranchNode (tqparent, id, name); }
-            TreeGroupNode *makeGroupNode (TreeNode *tqparent, pkgTagSection s)
-            { return new TreeGroupNode (tqparent, s); }
+            TreePkgNode *makePkgNode (TreeNode *parent, pkgCache::PkgIterator P)
+            { return new TreePkgNode (parent, P); }
+            TreeBranchNode *makeBranchNode (TreeNode *parent, string id, string name)
+            { return new TreeBranchNode (parent, id, name); }
+            TreeGroupNode *makeGroupNode (TreeNode *parent, pkgTagSection s)
+            { return new TreeGroupNode (parent, s); }
             TreeBranchNode *makeRoot () { return new TreeBranchNode (0, "ROOT"); }
-            TreeDepNode *makeDepNode (TreeNode *tqparent, pkgCache::DepIterator) { return 0; }
-            TreeVerNode *makeVerNode (TreeNode *tqparent, pkgCache::VerIterator) { return 0; }
+            TreeDepNode *makeDepNode (TreeNode *parent, pkgCache::DepIterator) { return 0; }
+            TreeVerNode *makeVerNode (TreeNode *parent, pkgCache::VerIterator) { return 0; }
     };
 
     /* class TestProd: public NodeProducer {
diff --git a/adept/adept/lister.cpp b/adept/adept/lister.cpp
index 254b0bc..4b2e812 100644
--- a/adept/adept/lister.cpp
+++ b/adept/adept/lister.cpp
@@ -40,8 +40,8 @@ TQPixmap* main_icon = 0;
 TQPixmap* non_main_icon = 0;
 #endif
 
-Lister::Lister( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ),
+Lister::Lister( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ),
       m_rangeProvider( 0 ),
       m_baseF( predicate::True< entity::Entity >() ),
       m_interactiveF( True<entity::Entity>() ), m_itemCount( -1 ),
@@ -179,7 +179,7 @@ void Lister::cleanRebuild()
 }
 
 Lister::CreateItem::CreateItem( Lister *_l, ListerItem *p )
-    : l( _l ), time( 0 ), items( 0 ), last( 0 ), tqparent( p )
+    : l( _l ), time( 0 ), items( 0 ), last( 0 ), parent( p )
 {
 }
 
@@ -204,19 +204,19 @@ Lister::Map::value_type Lister::CreateItem::operator()( entity::Entity e )
     }
 
     if ( last ) {
-        if ( tqparent )
-            last = new ListerItem( tqparent, last, e );
+        if ( parent )
+            last = new ListerItem( parent, last, e );
         else
             last = new ListerItem( l, last, e );
     } else {
-        if ( tqparent )
-            last = new ListerItem( tqparent, e );
+        if ( parent )
+            last = new ListerItem( parent, e );
         else
             last = new ListerItem( l, e );
     }
     l->m_rebuildMutex.unlock();
     if ( e.is< entity::Relation >() )
         // this should be safe because the tqparent thread is waiting
         // for us and ensures that universe (libapt-front) is kept
         // unchanged while we run
         l->insertRangeInternal( InsertRangePair(
@@ -535,8 +535,8 @@ ListerItemExtender::~ListerItemExtender()
 {
 }
 
-ListerItemExtender::ListerItemExtender( TQWidget *tqparent, const char * n)
-    : ListerItemExtenderUi( tqparent, n )
+ListerItemExtender::ListerItemExtender( TQWidget *parent, const char * n)
+    : ListerItemExtenderUi( parent, n )
 {
     observeComponent< component::State >();
     adjustFontSize( m_description, -1 );
@@ -204,19 +204,19 @@ Lister::Map::value_type Lister::CreateItem::operator()( entity::Entity e )
     l->m_rebuildMutex.unlock();
     if ( e.is< entity::Relation >() )
-        // this should be safe because the tqparent thread is waiting
+        // this should be safe because the parent thread is waiting
         // for us and ensures that universe (libapt-front) is kept
         // unchanged while we run
diff --git a/adept/libadept/lister.cpp b/adept/libadept/lister.cpp
index fc45699..a48b906 100644
--- a/adept/libadept/lister.cpp
+++ b/adept/libadept/lister.cpp
@@ -33,8 +33,8 @@ using namespace aptFront::cache;
 using namespace aptFront::utils;
 using namespace adept;
 
-Lister::Lister( TQWidget *tqparent, const char *name )
-    : ExtendableList( tqparent, name ),
+Lister::Lister( TQWidget *parent, const char *name )
+    : ExtendableList( parent, name ),
       m_rangeProvider( 0 ),
       m_baseF( predicate::True< entity::Entity >() ),
       m_interactiveF( True<entity::Entity>() ), m_itemCount( -1 ),
@@ -156,7 +156,7 @@ void Lister::cleanRebuild()
 }
 
 Lister::CreateItem::CreateItem( Lister *_l, ListerItem *p )
-    : l( _l ), time( 0 ), items( 0 ), last( 0 ), tqparent( p )
+    : l( _l ), time( 0 ), items( 0 ), last( 0 ), parent( p )
 {
 }
 
@@ -181,19 +181,19 @@ Lister::Map::value_type Lister::CreateItem::operator()( entity::Entity e )
     }
 
     if ( last ) {
-        if ( tqparent )
-            last = new ListerItem( tqparent, last, e );
+        if ( parent )
+            last = new ListerItem( parent, last, e );
         else
             last = new ListerItem( l, last, e );
     } else {
-        if ( tqparent )
-            last = new ListerItem( tqparent, e );
+        if ( parent )
+            last = new ListerItem( parent, e );
         else
             last = new ListerItem( l, e );
     }
     l->m_rebuildMutex.unlock();
     if ( e.is< entity::Relation >() )
         // this should be safe because the tqparent thread is waiting
         // for us and ensures that universe (libapt-front) is kept
         // unchanged while we run
         l->insertRangeInternal( InsertRangePair(
@@ -465,8 +465,8 @@ ListerItemExtender::~ListerItemExtender()
 {
 }
 
-ListerItemExtender::ListerItemExtender( TQWidget *tqparent, const char * n)
-    : ListerItemExtenderUi( tqparent, n )
+ListerItemExtender::ListerItemExtender( TQWidget *parent, const char * n)
+    : ListerItemExtenderUi( parent, n )
 {
     observeComponent< component::State >();
     adjustFontSize( m_description, -1 );
@@ -181,19 +181,19 @@ Lister::Map::value_type Lister::CreateItem::operator()( entity::Entity e )
     l->m_rebuildMutex.unlock();
     if ( e.is< entity::Relation >() )
-        // this should be safe because the tqparent thread is waiting
+        // this should be safe because the parent thread is waiting
         // for us and ensures that universe (libapt-front) is kept
         // unchanged while we run
-- 
cgit v1.2.3

